From dec7711a92d51b65bf95588c7d077e7c08d3f6a9 Mon Sep 17 00:00:00 2001
From: Nathan Bossart <bossartn@amazon.com>
Date: Fri, 19 Feb 2021 01:08:45 +0000
Subject: [PATCH v2] Small documentation fix for SET ROLE.

This change clarifies the behavior of RESET ROLE when "role" is set
per-user, per-database, or via command-line options.  Also, it adds
configuration parameter entries for "role" and
"session_authorization".
---
 doc/src/sgml/config.sgml       | 43 ++++++++++++++++++++++++++++++++++++++++++
 doc/src/sgml/ref/set_role.sgml |  7 ++++++-
 2 files changed, 49 insertions(+), 1 deletion(-)

diff --git a/doc/src/sgml/config.sgml b/doc/src/sgml/config.sgml
index e81141e45c..3150cda8aa 100644
--- a/doc/src/sgml/config.sgml
+++ b/doc/src/sgml/config.sgml
@@ -9220,6 +9220,49 @@ dynamic_library_path = 'C:\tools\postgresql;H:\my_project\lib;$libdir'
       </listitem>
      </varlistentry>
 
+     <varlistentry id="guc-role" xreflabel="role">
+      <term><varname>role</varname> (<type>string</type>)
+      <indexterm>
+       <primary><varname>role</varname> configuration parameter</primary>
+      </indexterm>
+      </term>
+      <listitem>
+       <para>
+        Sets the current user identifier.  See
+        <link linkend="sql-set-role"><command>SET ROLE</command></link> for more
+        information.
+       </para>
+       <para>
+        This parameter can only be changed at connection start via
+        <link linkend="libpq-connect-options">command-line options</link> or at
+        run time via <link linkend="sql-set"><command>SET</command></link>,
+        <link linkend="sql-set-role"><command>SET ROLE</command></link>,
+        <link linkend="sql-alterrole"><command>ALTER ROLE</command></link>, or
+        <link linkend="sql-alterdatabase"><command>ALTER DATABASE</command></link>.
+       </para>
+      </listitem>
+     </varlistentry>
+
+     <varlistentry id="guc-session-authorization" xreflabel="session_authorization">
+      <term><varname>session_authorization</varname> (<type>string</type>)
+      <indexterm>
+       <primary><varname>session_authorization</varname> configuration parameter</primary>
+      </indexterm>
+      </term>
+      <listitem>
+       <para>
+        Sets the session user identifier and the current user identifier.  See
+        <link linkend="sql-set-session-authorization"><command>SET SESSION AUTHORIZATION</command></link>
+        for more information.
+       </para>
+       <para>
+        This parameter can only be changed at run time via
+        <link linkend="sql-set"><command>SET</command></link> or
+        <link linkend="sql-set-session-authorization"><command>SET SESSION AUTHORIZATION</command></link>.
+       </para>
+      </listitem>
+     </varlistentry>
+
      </variablelist>
     </sect2>
    </sect1>
diff --git a/doc/src/sgml/ref/set_role.sgml b/doc/src/sgml/ref/set_role.sgml
index 739f2c5cdf..a69bfeae24 100644
--- a/doc/src/sgml/ref/set_role.sgml
+++ b/doc/src/sgml/ref/set_role.sgml
@@ -54,7 +54,12 @@ RESET ROLE
 
   <para>
    The <literal>NONE</literal> and <literal>RESET</literal> forms reset the current
-   user identifier to be the current session user identifier.
+   user identifier to the default value.  The default value is whatever value it
+   would be if no <command>SET</command> had been executed in the current
+   session.  This can be the command-line option value, the per-database default
+   setting, or the per-user default setting for the role, if any such settings
+   exist.  Otherwise, the default value will be the current session user
+   identifier.
    These forms can be executed by any user.
   </para>
  </refsect1>
-- 
2.16.6

